%define release	C1

Summary:   ProFTPD -- Professional FTP Server.
Name:      proftpd
Version:   1.2.5
Release:   stackguard%{release}
Source:    ftp://ftp.proftpd.org/distrib/%{name}-%{version}.tar.gz
Copyright: GPL
Group:     System Environment/Daemons
Requires:  pam >= 0.56, sed
Provides:  ftpserver
Prereq:    fileutils
BuildRoot: /var/tmp/%{name}-%{version}-root

# Additional Sources
Source1:   proftpd.log
Source2:   ftpd.xinetd
#Source3:   ftpd.pam
Source4:   ftpusers

# Additional Patches
Patch0:    proftpd-1.2.2rc2.patch
#Patch1:    proftpd-pr1426.patch

%description
ProFTPD is an enhanced FTP server with a focus toward simplicity, security,
and ease of configuration.  It features a very Apache-like configuration
syntax, and a highly customizable server infrastructure, including support for
multiple 'virtual' FTP servers, anonymous FTP, and permission-based directory
visibility.

%prep
if [ -x /usr/sg/bin/gcc ]; then
  PATH=/usr/sg/bin:$PATH
  export PATH
else
  echo "ERROR: No stackguard environment detected on this system"
  echo "Please obtain the stackguard environment RPMS located at:"
  echo "glazed:/fargo/i386/sg-cpp-1.1.2-30_SG201_cobalt.i386.rpm and"
  echo "glazed:/fargo/i386/sg-egcs-1.1.2-30_SG201_cobalt.i386.rpm"
  exit 1;
fi

%setup -q
echo "MY PATH IS $PATH"
./configure \
	--prefix=/usr \
	--sysconfdir=/etc \
	--localstatedir=/var/run \
	--with-modules=mod_pam:mod_linuxprivs:mod_ratio:mod_readme \
	--disable-sendfile

%patch0 -p1
#%patch1 -p1

%build
PATH=/usr/sg/bin:$PATH ; export PATH
make CFLAGS="$RPM_OPT_FLAGS"

%install
PATH=/usr/sg/bin:$PATH ; export PATH
rm -rf $RPM_BUILD_ROOT
make \
	prefix=$RPM_BUILD_ROOT/usr \
	localstatedir=$RPM_BUILD_ROOT/var/run \
	rundir=$RPM_BUILD_ROOT/var/run/proftpd \
	install
mkdir -p $RPM_BUILD_ROOT/etc/logrotate.d
install -m 644 %{SOURCE1} $RPM_BUILD_ROOT/etc/logrotate.d/proftpd
cp %{SOURCE4}  $RPM_BUILD_ROOT/etc/ftpusers

# xinetd
mkdir -p $RPM_BUILD_ROOT/etc/xinetd.d
install -m 644 %{SOURCE2} $RPM_BUILD_ROOT/etc/xinetd.d/proftp

# pam support
#mkdir -p $RPM_BUILD_ROOT/etc/pam.d
#install -m 644 %{SOURCE3} $RPM_BUILD_ROOT/etc/pam.d/ftp

%post

# Delete the info under /var/run/proftpd directory 
# or a PAM error happens after upgrading.
if [ -d /var/run/proftpd ]; then
        rm -rf /var/run/proftpd/*
fi

# conditionally look in inetd.conf
if [ -e /etc/inetd.conf ]; then
	# Look if there is already an entry for 'ftp' service
	grep '^[#[:space:]]*ftp' /etc/inetd.conf > /dev/null
	errcode=$?
	if [ $errcode -eq 0 ]; then
		# Found, replace the 'in.ftpd' with 'in.proftpd'
		tmpfile=/tmp/proftpd-inetd.$$
		sed	-e '/^[#[:space:]]*ftp/{' \
			-e 's^in.ftpd.*$^in.proftpd^' \
			-e '}' \
			/etc/inetd.conf \
		> $tmpfile
		mv $tmpfile /etc/inetd.conf
	else
	# Not found, append a new entry.
		echo 'ftp      stream  tcp     nowait  root    /usr/sbin/tcpd  in.proftpd' >> /etc/inetd.conf
	fi
fi

%preun
if [ $1 = 0 ]; then
	if [ -d /var/run/proftpd ]; then
		rm -rf /var/run/proftpd/*
	fi
fi

%postun
if [ $1 = 0 ]; then
	if [ -d /var/run/proftpd ]; then
		rm -rf /var/run/proftpd
	fi

	# Remove ProFTPD entry from /etc/inetd.conf
	tmpfile=/tmp/proftpd-inetd.$$
	if [ -e /etc/inetd.conf ]; then
		sed -e '/^.*proftpd.*$/d' /etc/inetd.conf > $tmpfile
		mv $tmpfile /etc/inetd.conf
		killall -HUP inetd || :
	fi
fi

%clean
rm -rf $RPM_BUILD_ROOT

%files
%attr(-,root,man) /usr/man/*/*
%doc README README.* doc/*
%doc contrib/README contrib/README.mod_wrap contrib/README.ratio contrib/xferstats.holger-preiss
%doc sample-configurations/*
%config(noreplace) /etc/logrotate.d/proftpd
%config(noreplace) /etc/ftpusers
%config /etc/xinetd.d/proftp
#%config /etc/pam.d/ftp
/usr/sbin/*
/usr/bin/*

%dir /var/run/proftpd

%changelog
* Fri Aug 23 2002 Jesse Throwe <jesse.throwe@sun.com> 1.2.5-C1
- PR 15823, Security Patch.  FTP assigns random permissions to uploaded files.
- Upgraded to 1.2.5.
- Removed patch1, pr1426.  Already merged into source in 1.2.5.

* Fri Aug 16 2002 Stephen Grell <stephen.grell@sun.com> 1.2.4-C5
- modify default /etc/ftpusers to include all system accounts
  with the exception of admin and root-admin

* Fri Jan 25 2002 Jeff Lovell <jeffrey.lovell@sun.com> 1.2.4-C4
- pr 13576.  add default /etc/ftpusers

* Fri Jan 25 2002 Patrick Baltz <patrick.baltz@sun.com> 1.2.4-C3
- pr 13570.  fix broken symlinks.

* Tue Oct 23 2001 Jeff Lovell <jeffrey.lovell@sun.com> 1.2.4-C1
- upgrade to 1.2.4

* Mon Oct 01 2001 Jeff Lovell <jeffrey.lovell@sun.com> 1.2.2-C3
- fix getpw* functions for pwdb

* Thu Sep 9 2001 Jeff Lovell <jeffrey.lovell@sun.com> 1.2.2-C2
- added xinetd support
- added proper pam support file
- conditionally modify /etc/inetd.conf

* Wed Aug 22 2001 Jeff Lovell <jeffrey.lovell@sun.com> 1.2.2-C1
- upgrade to 1.2.2 final release

* Wed Jun 20 2001 Jeff Lovell <jeffrey.lovell@sun.com>
- 1.2.2rc3-C1
- portability fixes from the proftpd group

* Mon Apr 12 2001 Brenda Mula <brenda.mula@sun.com> 1.2.2rc1-C2
- recompile to not be compiled against glibc 2.2 which breaks on
- older products.

* Mon Mar 26 2001 Patrick Baltz <patrick.baltz@sun.com> 1.2.2rc1-1C1
- update to latest version, which is a release candidate due to DoS
  vulnerability in 1.2.1 and earlier

* Mon Dec 04 2000 Rene Hendrix <rhendrix@cobalt.com>
- rc2 (based of of rc2-C2) replaces proftpd.log (the logrotate file)
  with our version of the logrotate file

* Thu Aug 31 2000 Jeff Lovell <jlovell@cobalt.com>
- rc2 + mod_xfer cvs patch for passive connections

* Fri Aug 30 2000 Brenda Mula <bmula@cobalt.com>
- rc2 
- got latest version, problem with chmod working correctly.
* Fri Jul 14 2000 Brenda Mula <bmula@cobalt.com>
- rc1 
- got newest version of proftpd

* Wed Jan 12 2000 Jeff Bilicki <jeffb@cobalt.com>
- pre9-C6
- added proftpd-1.2.0pre9-pwgrent.patch

* Wed Dec 15 1999 Jeff Lovell <jlovell@cobalt.com>
- pre9-C5
- disabled sendfile to speed up gets
- added mod_xfer.c.patch to fix have_sendfile decleration

* Wed Dec 15 1999 Jeff Bilicki <jeffb@cobalt.com>
- pre9-C4
- Added patch to fix bug in fgetgrent (glibc)
- Now uses internal function calls

* Tue Dec 14 1999 Jeff Lovell <jlovell@cobalt.com>
- 1.2.0pre9-C1
- CVS snapshot to fix y2k logging issues

* Wed Nov 9 1999 Duncan Laurie <duncan@cobalt.com>
- C5
- killall doesn't exist on new systems, don't try and call it

* Sun Sep 19 1999 Timothy Stonis <tim@cobaltnet.com>

 -C4 -> fix logrotate so missing log is okay

* Tue Sep 14 1999 Timothy Stonis <tim@cobaltnet.com>
-Fix log rotate typo

* Tue Sep 14 1999 Duncan Laurie <duncan@cobaltnet.com>
- 1.2.0pre6-C2
- fix proftpd.conf location

* Sat Sep 11 1999 Duncan Laurie <duncan@cobaltnet.com>
- 1.2.0pre6-C1
- remove proftpd.conf from this rpm
- put in logrotate configuration fro harris

* Sat Jul 24 1999 MacGyver <macgyver@tos.net>
  Initial import of spec.

